LavueController Tango Class Attribute BeamCenterX

Attribute BeamCenterX :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | beam center x
unit | pixels
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false